<?php
/*
 * Plugin Name: Advanced Order Export  - Custom JSON format
 * Description: Custom JSON Export 
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


class Woe_Custom_JSON {
    function __construct() {
		//add checkbox above buttons
		add_action("woe_settings_above_buttons", function ($settings){
			$selected = !empty($settings[ 'custom_json_format' ]) ? 'checked': '';
			echo '<br><br>
			<input type=hidden name="settings[custom_json_format]" value="0">
			<input type=checkbox name="settings[custom_json_format]" value="1" '. $selected .'>
			Custom JSON format<br><br>';
		});
		
		//activate hooks only when export starts
		add_filter('woe_settings_validate_defaults', function ($settings) {
			if( !empty($settings['custom_json_format']) ) {
				$settings['format'] = "JSON";//force format 
				add_filter("woe_json_output_filter", array($this,"woe_json_make_order"), 10, 2 );
			}	
			return $settings;
		} );        
    }
    
	function woe_json_make_order($xml,$data) {
		// get order 
		$order = new WC_Order(WC_Order_Export_Engine::$order_id);

		$data = array();
		
		// top
		$data['OrderNumber']= $order->get_order_number();
		$data['CustomerNumber'] = $order->get_user_id();

		// addresses
		$data['Address'] = array();
		
		$data['Address']['Billing'] = array();
		$data['Address']['Billing']['FirstName'] = $order->get_billing_first_name();
		$data['Address']['Billing']['LastName'] = $order->get_billing_last_name();
		$data['Address']['Billing']['Street'] = trim( $order->get_billing_address_1() . " " . $order->get_billing_address_2() );
		$data['Address']['Billing']['Zipcode'] = $order->get_billing_postcode();
		$data['Address']['Billing']['City'] = $order->get_billing_city();
		
		$data['Address']['Shipping'] = array();
		$data['Address']['Shipping']['FirstName'] = $order->get_shipping_first_name();
		$data['Address']['Shipping']['LastName'] = $order->get_shipping_last_name();
		$data['Address']['Shipping']['Street'] = trim( $order->get_shipping_address_1() . " " . $order->get_shipping_address_2() );
		$data['Address']['Shipping']['Zipcode'] = $order->get_shipping_postcode();
		$data['Address']['Shipping']['City'] = $order->get_shipping_city();

		// items
		$data['LineItems'] = array();
		foreach ( $order->get_items('line_item') as $item_id=>$item ) {
			$product   = $order->get_product_from_item( $item );
			$item_meta = $order->get_item_meta( $item_id );

			$itemJSON = array();
			$itemJSON['Id'] = $product->get_sku();
			$itemJSON['Name'] = $item['name'];
			$itemJSON['Quantity'] = $item['qty'];
			$data['LineItems'][]= $itemJSON;
		}
		
		// shipment 
		$data['Shipping'] = array();
		$shipping_methods = $order->get_items( 'shipping' );
		$shipping_method = reset($shipping_methods); // take first entry
		$shipping_method_id =  !empty($shipping_method) ?  $shipping_method['method_id'] : '' ;
		$data['Shipping']['Id'] = $shipping_method_id;
		$data['Shipping']['TotalPrice'] = $order->get_total_shipping();
		$data['Shipping']['Name'] = $order->get_shipping_method();

		// payment 
		$data['Payment'] = array();
		$data['Payment']['Id'] = $order->get_payment_method();
		$data['Payment']['TotalPrice'] = $order->get_total();
		$data['Payment']['Name'] = $order->get_payment_method_title();

		//bottom
		$data['CreationDate'] = $order->get_date_created() ? gmdate( 'Y-m-d H:i:s', $order->get_date_created()->getOffsetTimestamp() ) : '';
		$data['ShippedOn'] = $order->get_date_completed() ? gmdate( 'Y-m-d H:i:s', $order->get_date_completed()->getOffsetTimestamp() ) : '';

		//format it!
		if ( WC_Order_Export_Engine::$current_job_build_mode == 'preview' ) {
			$json = json_encode( $data, JSON_PRETTY_PRINT );
		} else {
			$json = json_encode( $data );
		}
		return  $json;
	}    
}
new Woe_Custom_JSON();